<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Perjungti į langą</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Perjungti į visą ekraną</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Sąranka buvo sėkminga.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Užverkite šį langą ir dar kartą paleiskite vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Gero laiko su vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nerasta jokios failų tvarkytuvės.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Įdiekite failų tvarkytuvę.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Įrašinėjimas nepradėtas, trūksta laisvos vietos diske.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Yra pasiekta laisvos vietos diske riba.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Laisvos vietos diske apribojimas</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabaitų</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Įrašinėjimas buvo sustabdytas, trūksta laisvos vietos diske.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Langas</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Nerasta jokios failų tvarkytuvės.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Įdiekite failų tvarkytuvę.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Pirminis kodas</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Svetainė</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Vertimai</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Paaukoti</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Sritis</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Sritis</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nerasta jokios failų tvarkytuvės.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Įdiekite failų tvarkytuvę.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Pradėti</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tęsti</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Didinimas</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Pradėti</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tęsti</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Didinimas</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogas</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Apversti horizontaliai</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Apversti vertikaliai</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertuoti</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Pilka</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Juoda ir balta</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Šalinti lango rėmelį</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kameros nustatymai</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Sritis</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Atstatyti</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Didinimas</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Atvirkštinis skaičiavimas</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Vaizdo dydis:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Laisva vieta diske:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Įrašinėjimo laikas:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Garsas</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Kadrai</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Vaizdo kodekas</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatas</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Garso kodekas</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kokybė</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Neįrašinėti pelės žymeklio</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Val.</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Min.</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Paleisti laikmatį</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stabdyti įrašinėjimą po</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Val.</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Min.</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sek.</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Vaizdo įrašo kelias</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Laisvos vietos diske apribojimas</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Rodyti sistemos dėkle</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Luktelėti sekundėlę prieš įrašinėjant</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Tikrinti ar yra atnaujinimų</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vaizdas</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Prieinama</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Neprieinama</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Pradėti</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tęsti</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Aplankas</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertuoti</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Pilka</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>VALD+LYG2+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>VALD+LYG2+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>VALD+LYG2+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Groti paskiausią įrašą</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti aplanką</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>VALD+LYG2+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Prasidėjus įrašinėjimui, suskleisti</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Pasileidžia suskleista</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Apversti horizontaliai</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Apversti vertikaliai</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Juoda ir balta</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Šalinti lango rėmelį</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Paaukoti</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Kito paleidimo metu atstatyti visus nustatymus</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Autorių teisės ir licencijos iš paveikslų</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabaitų</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Ekrano įrašas</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Grotuvas</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Žurnalas</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automatiškai</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Sukurti kortelių paveikslus</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informacija apie licenciją</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ĮJUNGTA</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>IŠJUNGTA</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Visuotiniai spartieji klavišai</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Spartieji klavišai priskirti.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Spartusis klavišas nepriskirtas arba priskirtas daugiau kaip vieną kartą.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Jei yra rodoma, jog jis yra priskirtas, o jis neveikia, vadinasi jį naudoja kita programa.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Momentinė kopija</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Paveikslo kelias</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Slėpti šį langą</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Kiek sekundžių laukti, prieš įrašinėjant</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Autorių teisės ir licencijos iš paveikslų</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Atverti failą</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Ankstesnis kadras</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Kitas kadras</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Perkelti meniu</translation>
    </message>
</context>
</TS>